diff src/util.h @ 10203:7ff9b8b22e7d

[gaim-migrate @ 11324] gaim_mkstemp can now create binary files committer: Tailor Script <tailor@pidgin.im>
author Herman Bloggs <hermanator12002@yahoo.com>
date Thu, 18 Nov 2004 17:05:40 +0000
parents b23e70bd1215
children 357d4fa1bfbe
line wrap: on
line diff
--- a/src/util.h	Wed Nov 17 23:54:24 2004 +0000
+++ b/src/util.h	Thu Nov 18 17:05:40 2004 +0000
@@ -387,11 +387,12 @@
  * done, as well as freeing the space pointed to by @a path with
  * g_free().
  *
  * @param path The returned path to the temp file.
  *
  * @return A file pointer to the temporary file, or @c NULL on failure.
  */
-FILE *gaim_mkstemp(char **path);
+FILE *gaim_mkstemp(char **path, gboolean binary);
 
 /**
  * Checks if the given program name is valid and executable.
@@ -387,11 +387,12 @@
  * g_free().
  *
- * @param path The returned path to the temp file.
+ * @param path   The returned path to the temp file.
+ * @param binary Text or binary, for platforms where it matters.
  *
  * @return A file pointer to the temporary file, or @c NULL on failure.